@@ -14,8 +14,6 @@
 #include <KFileItemListProperties>
 #include <KIO/CopyJob>
 #include <KIO/DeleteJob>
-#include <KIO/FileUndoManager>
-#include <KIO/JobUiDelegate>
 #include <KIO/Paste>
 #include <KIO/PasteJob>
 #include <KJobWidgets>
@@ -24,6 +22,14 @@
 #include <KSharedConfig>
 #include <KUrlMimeData>
 
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+#include <KIO/DeleteOrTrashJob>
+#else
+#include <KIO/FileUndoManager>
+#include <KIO/JobUiDelegate>
+#endif
+
 #include <QApplication>
 #include <QClipboard>
 #include <QMenu>
@@ -193,6 +199,11 @@ void TreeViewContextMenu::rename()
 
 void TreeViewContextMenu::moveToTrash()
 {
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    using Iface = KIO::AskUserActionInterface;
+    auto *deleteJob = new KIO::DeleteOrTrashJob(QList{m_fileItem.url()}, Iface::Trash, Iface::DefaultConfirmation, m_parent);
+    deleteJob->start();
+#else
     const QList<QUrl> list{m_fileItem.url()};
     KIO::JobUiDelegate uiDelegate;
     uiDelegate.setWindow(m_parent);
@@ -202,10 +213,16 @@ void TreeViewContextMenu::moveToTrash()
         KJobWidgets::setWindow(job, m_parent);
         job->uiDelegate()->setAutoErrorHandlingEnabled(true);
     }
+#endif
 }
 
 void TreeViewContextMenu::deleteItem()
 {
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    using Iface = KIO::AskUserActionInterface;
+    auto *deleteJob = new KIO::DeleteOrTrashJob(QList{m_fileItem.url()}, Iface::Delete, Iface::DefaultConfirmation, m_parent);
+    deleteJob->start();
+#else
     const QList<QUrl> list{m_fileItem.url()};
     KIO::JobUiDelegate uiDelegate;
     uiDelegate.setWindow(m_parent);
@@ -214,6 +231,7 @@ void TreeViewContextMenu::deleteItem()
         KJobWidgets::setWindow(job, m_parent);
         job->uiDelegate()->setAutoErrorHandlingEnabled(true);
     }
+#endif
 }
 
 void TreeViewContextMenu::showProperties()
